/* 8BitAmEthernet
 * version 0.2.1 date 2005-03-08
 * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
 * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
 * a project of CCC-AC - http://www.cccac.de/
 */

#ifndef INC_config
#define INC_config

//MAC address
extern unsigned char ConfigMac[6];

//IP configuration
extern unsigned char ConfigIp[4]; //own IP address
extern unsigned char ConfigMask[4]; //subnet mask
extern unsigned char ConfigGw[4]; //gateway IP address

//port for S8P
extern unsigned short ConfigS8pPort; //disabled if 0

//symmetric key for S8P
extern unsigned char ConfigS8pKey[16];

//port for webserver
extern unsigned short ConfigWebPort; //disabled if 0

//default output state
extern unsigned char ConfigDefOut;

#endif //#ifndef INC_config
